@@ -6,9 +6,9 @@ Type annotations for appflow service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_appflow.literals import AggregationType
+    from mypy_boto3_appflow.literals import AggregationTypeType
 
-    data: AggregationType = "None"
+    data: AggregationTypeType = "None"
     ```
 """
 import sys
@@ -20,42 +20,42 @@ else:
 
 
 __all__ = (
-    "AggregationType",
-    "AmplitudeConnectorOperator",
-    "ConnectionMode",
-    "ConnectorType",
-    "DataPullMode",
-    "DatadogConnectorOperator",
-    "DynatraceConnectorOperator",
-    "ExecutionStatus",
-    "FileType",
-    "FlowStatus",
-    "GoogleAnalyticsConnectorOperator",
-    "InforNexusConnectorOperator",
-    "MarketoConnectorOperator",
-    "Operator",
-    "OperatorPropertiesKeys",
-    "PrefixFormat",
-    "PrefixType",
-    "S3ConnectorOperator",
-    "SalesforceConnectorOperator",
-    "ScheduleFrequencyType",
-    "ServiceNowConnectorOperator",
-    "SingularConnectorOperator",
-    "SlackConnectorOperator",
-    "TaskType",
-    "TrendmicroConnectorOperator",
-    "TriggerType",
-    "VeevaConnectorOperator",
-    "WriteOperationType",
-    "ZendeskConnectorOperator",
+    "AggregationTypeType",
+    "AmplitudeConnectorOperatorType",
+    "ConnectionModeType",
+    "ConnectorTypeType",
+    "DataPullModeType",
+    "DatadogConnectorOperatorType",
+    "DynatraceConnectorOperatorType",
+    "ExecutionStatusType",
+    "FileTypeType",
+    "FlowStatusType",
+    "GoogleAnalyticsConnectorOperatorType",
+    "InforNexusConnectorOperatorType",
+    "MarketoConnectorOperatorType",
+    "OperatorPropertiesKeysType",
+    "OperatorType",
+    "PrefixFormatType",
+    "PrefixTypeType",
+    "S3ConnectorOperatorType",
+    "SalesforceConnectorOperatorType",
+    "ScheduleFrequencyTypeType",
+    "ServiceNowConnectorOperatorType",
+    "SingularConnectorOperatorType",
+    "SlackConnectorOperatorType",
+    "TaskTypeType",
+    "TrendmicroConnectorOperatorType",
+    "TriggerTypeType",
+    "VeevaConnectorOperatorType",
+    "WriteOperationTypeType",
+    "ZendeskConnectorOperatorType",
 )
 
 
-AggregationType = Literal["None", "SingleFile"]
-AmplitudeConnectorOperator = Literal["BETWEEN"]
-ConnectionMode = Literal["Private", "Public"]
-ConnectorType = Literal[
+AggregationTypeType = Literal["None", "SingleFile"]
+AmplitudeConnectorOperatorType = Literal["BETWEEN"]
+ConnectionModeType = Literal["Private", "Public"]
+ConnectorTypeType = Literal[
     "Amplitude",
     "CustomerProfiles",
     "Datadog",
@@ -78,8 +78,8 @@ ConnectorType = Literal[
     "Veeva",
     "Zendesk",
 ]
-DataPullMode = Literal["Complete", "Incremental"]
-DatadogConnectorOperator = Literal[
+DataPullModeType = Literal["Complete", "Incremental"]
+DatadogConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "DIVISION",
@@ -96,7 +96,7 @@ DatadogConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-DynatraceConnectorOperator = Literal[
+DynatraceConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "DIVISION",
@@ -113,11 +113,11 @@ DynatraceConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-ExecutionStatus = Literal["Error", "InProgress", "Successful"]
-FileType = Literal["CSV", "JSON", "PARQUET"]
-FlowStatus = Literal["Active", "Deleted", "Deprecated", "Draft", "Errored", "Suspended"]
-GoogleAnalyticsConnectorOperator = Literal["BETWEEN", "PROJECTION"]
-InforNexusConnectorOperator = Literal[
+ExecutionStatusType = Literal["Error", "InProgress", "Successful"]
+FileTypeType = Literal["CSV", "JSON", "PARQUET"]
+FlowStatusType = Literal["Active", "Deleted", "Deprecated", "Draft", "Errored", "Suspended"]
+GoogleAnalyticsConnectorOperatorType = Literal["BETWEEN", "PROJECTION"]
+InforNexusConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "DIVISION",
@@ -134,7 +134,7 @@ InforNexusConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-MarketoConnectorOperator = Literal[
+MarketoConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "DIVISION",
@@ -152,30 +152,7 @@ MarketoConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-Operator = Literal[
-    "ADDITION",
-    "BETWEEN",
-    "CONTAINS",
-    "DIVISION",
-    "EQUAL_TO",
-    "GREATER_THAN",
-    "GREATER_THAN_OR_EQUAL_TO",
-    "LESS_THAN",
-    "LESS_THAN_OR_EQUAL_TO",
-    "MASK_ALL",
-    "MASK_FIRST_N",
-    "MASK_LAST_N",
-    "MULTIPLICATION",
-    "NOT_EQUAL_TO",
-    "NO_OP",
-    "PROJECTION",
-    "SUBTRACTION",
-    "VALIDATE_NON_NEGATIVE",
-    "VALIDATE_NON_NULL",
-    "VALIDATE_NON_ZERO",
-    "VALIDATE_NUMERIC",
-]
-OperatorPropertiesKeys = Literal[
+OperatorPropertiesKeysType = Literal[
     "CONCAT_FORMAT",
     "DATA_TYPE",
     "DESTINATION_DATA_TYPE",
@@ -191,31 +168,7 @@ OperatorPropertiesKeys = Literal[
     "VALUE",
     "VALUES",
 ]
-PrefixFormat = Literal["DAY", "HOUR", "MINUTE", "MONTH", "YEAR"]
-PrefixType = Literal["FILENAME", "PATH", "PATH_AND_FILENAME"]
-S3ConnectorOperator = Literal[
-    "ADDITION",
-    "BETWEEN",
-    "DIVISION",
-    "EQUAL_TO",
-    "GREATER_THAN",
-    "GREATER_THAN_OR_EQUAL_TO",
-    "LESS_THAN",
-    "LESS_THAN_OR_EQUAL_TO",
-    "MASK_ALL",
-    "MASK_FIRST_N",
-    "MASK_LAST_N",
-    "MULTIPLICATION",
-    "NOT_EQUAL_TO",
-    "NO_OP",
-    "PROJECTION",
-    "SUBTRACTION",
-    "VALIDATE_NON_NEGATIVE",
-    "VALIDATE_NON_NULL",
-    "VALIDATE_NON_ZERO",
-    "VALIDATE_NUMERIC",
-]
-SalesforceConnectorOperator = Literal[
+OperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "CONTAINS",
@@ -238,8 +191,31 @@ SalesforceConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-ScheduleFrequencyType = Literal["BYMINUTE", "DAILY", "HOURLY", "MONTHLY", "ONCE", "WEEKLY"]
-ServiceNowConnectorOperator = Literal[
+PrefixFormatType = Literal["DAY", "HOUR", "MINUTE", "MONTH", "YEAR"]
+PrefixTypeType = Literal["FILENAME", "PATH", "PATH_AND_FILENAME"]
+S3ConnectorOperatorType = Literal[
+    "ADDITION",
+    "BETWEEN",
+    "DIVISION",
+    "EQUAL_TO",
+    "GREATER_THAN",
+    "GREATER_THAN_OR_EQUAL_TO",
+    "LESS_THAN",
+    "LESS_THAN_OR_EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NOT_EQUAL_TO",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
+SalesforceConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "CONTAINS",
@@ -262,62 +238,8 @@ ServiceNowConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-SingularConnectorOperator = Literal[
-    "ADDITION",
-    "DIVISION",
-    "EQUAL_TO",
-    "MASK_ALL",
-    "MASK_FIRST_N",
-    "MASK_LAST_N",
-    "MULTIPLICATION",
-    "NO_OP",
-    "PROJECTION",
-    "SUBTRACTION",
-    "VALIDATE_NON_NEGATIVE",
-    "VALIDATE_NON_NULL",
-    "VALIDATE_NON_ZERO",
-    "VALIDATE_NUMERIC",
-]
-SlackConnectorOperator = Literal[
-    "ADDITION",
-    "BETWEEN",
-    "DIVISION",
-    "EQUAL_TO",
-    "GREATER_THAN",
-    "GREATER_THAN_OR_EQUAL_TO",
-    "LESS_THAN",
-    "LESS_THAN_OR_EQUAL_TO",
-    "MASK_ALL",
-    "MASK_FIRST_N",
-    "MASK_LAST_N",
-    "MULTIPLICATION",
-    "NO_OP",
-    "PROJECTION",
-    "SUBTRACTION",
-    "VALIDATE_NON_NEGATIVE",
-    "VALIDATE_NON_NULL",
-    "VALIDATE_NON_ZERO",
-    "VALIDATE_NUMERIC",
-]
-TaskType = Literal["Arithmetic", "Filter", "Map", "Mask", "Merge", "Truncate", "Validate"]
-TrendmicroConnectorOperator = Literal[
-    "ADDITION",
-    "DIVISION",
-    "EQUAL_TO",
-    "MASK_ALL",
-    "MASK_FIRST_N",
-    "MASK_LAST_N",
-    "MULTIPLICATION",
-    "NO_OP",
-    "PROJECTION",
-    "SUBTRACTION",
-    "VALIDATE_NON_NEGATIVE",
-    "VALIDATE_NON_NULL",
-    "VALIDATE_NON_ZERO",
-    "VALIDATE_NUMERIC",
-]
-TriggerType = Literal["Event", "OnDemand", "Scheduled"]
-VeevaConnectorOperator = Literal[
+ScheduleFrequencyTypeType = Literal["BYMINUTE", "DAILY", "HOURLY", "MONTHLY", "ONCE", "WEEKLY"]
+ServiceNowConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
     "CONTAINS",
@@ -340,8 +262,86 @@ VeevaConnectorOperator = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-WriteOperationType = Literal["INSERT", "UPDATE", "UPSERT"]
-ZendeskConnectorOperator = Literal[
+SingularConnectorOperatorType = Literal[
+    "ADDITION",
+    "DIVISION",
+    "EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
+SlackConnectorOperatorType = Literal[
+    "ADDITION",
+    "BETWEEN",
+    "DIVISION",
+    "EQUAL_TO",
+    "GREATER_THAN",
+    "GREATER_THAN_OR_EQUAL_TO",
+    "LESS_THAN",
+    "LESS_THAN_OR_EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
+TaskTypeType = Literal["Arithmetic", "Filter", "Map", "Mask", "Merge", "Truncate", "Validate"]
+TrendmicroConnectorOperatorType = Literal[
+    "ADDITION",
+    "DIVISION",
+    "EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
+TriggerTypeType = Literal["Event", "OnDemand", "Scheduled"]
+VeevaConnectorOperatorType = Literal[
+    "ADDITION",
+    "BETWEEN",
+    "CONTAINS",
+    "DIVISION",
+    "EQUAL_TO",
+    "GREATER_THAN",
+    "GREATER_THAN_OR_EQUAL_TO",
+    "LESS_THAN",
+    "LESS_THAN_OR_EQUAL_TO",
+    "MASK_ALL",
+    "MASK_FIRST_N",
+    "MASK_LAST_N",
+    "MULTIPLICATION",
+    "NOT_EQUAL_TO",
+    "NO_OP",
+    "PROJECTION",
+    "SUBTRACTION",
+    "VALIDATE_NON_NEGATIVE",
+    "VALIDATE_NON_NULL",
+    "VALIDATE_NON_ZERO",
+    "VALIDATE_NUMERIC",
+]
+WriteOperationTypeType = Literal["INSERT", "UPDATE", "UPSERT"]
+ZendeskConnectorOperatorType = Literal[
     "ADDITION",
     "DIVISION",
     "GREATER_THAN",
